from distutils.core import setup

setup(
    name = 'XIEHW',
    version = '1.0',
    description = '第一次发布模块，进行测试',
    author = 'XieHongWei',
    author_email= '1323981989@qq.com',
    py_modules = ['XIEHW.modulepath']
)